==> hyperon_das_atomdb-0.1.3-py3-none-any.whl: hyperon_das_atomdb/i_database.py <==
from abc import ABC, abstractmethod
from typing import Any, List

WILDCARD = '*'
UNORDERED_LINK_TYPES = ['Similarity', 'Set']


class IAtomDB(ABC):
    def __repr__(self) -> str:
        return "<Atom database interface>"

    @abstractmethod
    def node_exists(self, node_type: str, node_name: str) -> bool:
        pass

    @abstractmethod
    def link_exists(self, link_type: str, targets: List[str]) -> bool:
        pass

    @abstractmethod
    def get_node_handle(self, node_type: str, node_name: str) -> str:
        pass

    @abstractmethod
    def get_link_handle(
        self, link_type: str, target_handles: List[str]
    ) -> str:
        pass

    @abstractmethod
    def get_link_targets(self, link_handle: str) -> List[str]:
        pass

    @abstractmethod
    def is_ordered(self, link_handle: str) -> bool:
        pass

    @abstractmethod
    def get_matched_links(self, link_type: str, target_handles: List[str]):
        pass

    @abstractmethod
    def get_all_nodes(self, node_type: str, names: bool = False) -> List[str]:
        pass

    @abstractmethod
    def get_matched_type_template(self, template: List[Any]) -> List[str]:
        pass

    @abstractmethod
    def get_matched_type(self, link_type: str):
        pass

    @abstractmethod
    def get_node_name(self, node_handle: str) -> str:
        pass

    @abstractmethod
    def get_matched_node_name(self, node_type: str, substring: str) -> str:
        pass

    def add_node(self, node_type: str, node_name: str) -> None:
        pass

    def add_atom(self, atom_type: str) -> None:
        pass

    def add_link(self, link_type: str, targets: List[str]) -> None:
        pass

    def get_atom_as_dict(self, handle: str, arity: int):
        pass

    def get_atom_as_deep_representation(self, handle: str, arity: int):
        pass

    def count_atoms(self):
        pass

    def clear_database(self) -> None:
        pass

==> hyperon_das_atomdb-0.1.5-py3-none-any.whl: hyperon_das_atomdb/i_database.py <==
from abc import ABC, abstractmethod
from typing import Any, List

WILDCARD = '*'
UNORDERED_LINK_TYPES = ['Similarity', 'Set']


class IAtomDB(ABC):
    def __repr__(self) -> str:
        return "<Atom database interface>"  # pragma no cover

    @abstractmethod
    def node_exists(self, node_type: str, node_name: str) -> bool:
        ...  # pragma no cover

    @abstractmethod
    def link_exists(self, link_type: str, targets: List[str]) -> bool:
        ...  # pragma no cover

    @abstractmethod
    def get_node_handle(self, node_type: str, node_name: str) -> str:
        ...  # pragma no cover

    @abstractmethod
    def get_link_handle(
        self, link_type: str, target_handles: List[str]
    ) -> str:
        ...  # pragma no cover

    @abstractmethod
    def get_link_targets(self, link_handle: str) -> List[str]:
        ...  # pragma no cover

    @abstractmethod
    def is_ordered(self, link_handle: str) -> bool:
        ...  # pragma no cover

    @abstractmethod
    def get_matched_links(self, link_type: str, target_handles: List[str]):
        ...  # pragma no cover

    @abstractmethod
    def get_all_nodes(self, node_type: str, names: bool = False) -> List[str]:
        ...  # pragma no cover

    @abstractmethod
    def get_matched_type_template(self, template: List[Any]) -> List[str]:
        ...  # pragma no cover

    @abstractmethod
    def get_matched_type(self, link_type: str):
        ...  # pragma no cover

    @abstractmethod
    def get_node_name(self, node_handle: str) -> str:
        ...  # pragma no cover

    @abstractmethod
    def get_matched_node_name(self, node_type: str, substring: str) -> str:
        ...  # pragma no cover

    def add_node(self, node_type: str, node_name: str) -> None:
        ...  # pragma no cover

    def add_link(self, link_type: str, targets: List[str]) -> None:
        ...  # pragma no cover

    def get_atom_as_dict(self, handle: str, arity: int):
        ...  # pragma no cover

    def get_atom_as_deep_representation(self, handle: str, arity: int):
        ...  # pragma no cover

    def count_atoms(self):
        ...  # pragma no cover

    def clear_database(self) -> None:
        ...  # pragma no cover
